@@ -6,7 +6,7 @@
 from pyArango.connection import *
 from pyArango.collection import *
 from pyArango.graph import *
-from BasicElement import BasicElement
+from .BasicElement import BasicElement
 import params
 
 class Metadata():
